//+------------------------------+
//|   Trade Position Management  |
//+==============================+
//|
//|   Rev Date: 2010.10.29
//|
//|   Contains the following Functions:
//|
//|   EquityAtRisk()
//|   ProfitPotential()
//|   LotSize()
//|   NormalizeLotSize()
//|
//+------------------------------+

#property copyright "1005phillip"
#include <stderror.mqh>
#include <stdlib.mqh>
#include <Analyze_Currency_Symbol_2010.10.29.mqh>

//+------------------------------+
//|   EquityAtRisk()             |
//+==============================+
//|
//|   double EquityAtRisk(double LotSize, double OpenPrice, double StopLossPrice, int CurrentOrderType, string symbol="NULL", bool verbose=false)
//|
//|   Computes the equity at risk for the impending trade based on the input lotsize and stoploss, i.e. the equity at risk is determined by the stops (the prices of the stops).
//|   Returns a double value representing the equity at risk (expressed as a positive value) if possible, otherwise, it returns a zero value.
//|
//|   Parameters:
//|      LotSize           -  Position size that will be used in the impending trade.
//|      OpenPrice         -  The proposed opening price for either a market order or a pending order
//|      StopLossPrice     -  The price at which point the stops will be activated and the position will be closed for total loss of the equity at risk.
//|      CurrentOrderType  -  Is the impending order type (OP_BUY, OP_SELLLIMIT, etc).
//|      symbol            -  Symbol of the currency pair to use in the called routine. NULL means the current symbol.
//|                           By default, symbol is taken to be Symbol() unless specified otherwise as a passed parameter.
//|      verbose           -  Determines whether Print messages are committed to the experts log. By default, print messages are disabled.
//|
//|   Sample:
//|
//|      CurrentLotSize=0.1;            // setting the position size at a fixed 0.1 lots
//|      CurrentOpenPrice= Ask;         // setting the open price to current Ask price
//|      CurrentStopLossPrice= 92.361   // setting the stops at a fixed price of 92.361
//|      CurrentEquityAtRisk=EquityAtRisk(CurrentLotSize,CurrentOpenPrice,CurrentStopLossPrice,OP_BUY,"USDJPY");
//|      Print("The calculated equity at risk of total loss is ",CurrentEquityAtRisk);
//|
//+-----------------------+

double EquityAtRisk(double LotSize,double OpenPrice,double StopLossPrice,int CurrentOrderType,string symbol="NULL",bool verbose=false)
   {  // EquityAtRisk body start
   string   CurrentSymbol=symbol;
   if(symbol=="NULL") CurrentSymbol=Symbol();
   
   int      CurrentSymbolType=SymbolType(CurrentSymbol);  //|      CurrentSymbolType -  The type of currency pair represented by CurrentSymbol.
            if(CurrentSymbolType==6)
               {
               Print("Internal Error in determination of SymbolType for currency pair ",CurrentSymbol,", exiting script without computing Equity at Risk");
               return(0);
               }
   string   CurrentCounterPairForCross=CounterPairForCross(CurrentSymbol);  //|      CurrentCounterPairForCross -  The name of the financial instrument which is the counter currency pair to CurrentSymbol (relevant to crosses)
   
   double   CalculatedEquityAtRisk=0.;
   
   switch(CurrentSymbolType) // Determine the equity at risk based on the SymbolType for the financial instrument
      {
      case 1   :  switch(CurrentOrderType)
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedEquityAtRisk=-MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(StopLossPrice-OpenPrice)/StopLossPrice; break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedEquityAtRisk=-MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(OpenPrice-StopLossPrice)/StopLossPrice; break;
                     default           :  Print("Error encountered in the OrderType() routine for calculating the EquityAtRisk"); // The expression did not generate a case value
                     }
                  break;
      case 2   :  switch(CurrentOrderType)
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedEquityAtRisk=-MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(StopLossPrice-OpenPrice); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedEquityAtRisk=-MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(OpenPrice-StopLossPrice); break;
                     default           :  Print("Error encountered in the OrderType() routine for calculating the EquityAtRisk"); // The expression did not generate a case value
                     }
                  break;
      case 3   :  // e.g. Symbol() = CHFJPY, the counter currency is JPY and the USD is the base to the JPY in the pair USDJPY
                  // falls thru and is treated the same as SymbolType()==4 for the purpose of these calculations
      case 4   :  switch(CurrentOrderType)  // e.g. Symbol() = AUDCAD, the counter currency is CAD and the USD is the base to the CAD in the pair USDCAD
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedEquityAtRisk=-MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(StopLossPrice-OpenPrice)/MarketInfo(CurrentCounterPairForCross,MODE_BID); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedEquityAtRisk=-MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(OpenPrice-StopLossPrice)/MarketInfo(CurrentCounterPairForCross,MODE_ASK); break;
                     default           :  Print("Error encountered in the OrderType() routine for calculating the EquityAtRisk"); // The expression did not generate a case value
                     }
                  break;
      case 5   :  switch(CurrentOrderType)  // e.g. Symbol() = EURGBP, the counter currency is GBP and the USD is the counter to the GBP in the pair GBPUSD
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedEquityAtRisk=-MarketInfo(CurrentSymbol,MODE_LOTSIZE)*MarketInfo(CurrentCounterPairForCross,MODE_BID)*LotSize*(StopLossPrice-OpenPrice); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedEquityAtRisk=-MarketInfo(CurrentSymbol,MODE_LOTSIZE)*MarketInfo(CurrentCounterPairForCross,MODE_ASK)*LotSize*(OpenPrice-StopLossPrice); break;
                     default           :  Print("Error encountered in the OrderType() routine for calculating the EquityAtRisk"); // The expression did not generate a case value
                     }
                  break;
      default  :  Print("Error encountered in the SWITCH routine for calculating the EquityAtRisk"); // The expression did not generate a case value
      }
   
   if(verbose==true) Print("The equity at risk with this trade is ",DoubleToStr(CalculatedEquityAtRisk,2));
   
   return(CalculatedEquityAtRisk);
   
   }  // EquityAtRisk body end

// Program End

//+-----------------------+
//|   ProfitPotential()   |
//+=======================+
//|
//|   double ProfitPotential(double LotSize, double OpenPrice, double TakeProfitPrice, int CurrentOrderType, string symbol="NULL", bool verbose=false)
//|
//|   Computes the profit gain based on the input lotsize, order OpenPrice and the TakeProfit price.
//|   Returns a double value representing the equity to be gained (expressed as a positive value) if possible, otherwise, it returns a zero value.
//|
//|   Parameters:
//|      LotSize           -  Position size that will be used in the impending trade.
//|      OpenPrice         -  The proposed opening price for either a market order or a pending order.
//|      TakeProfitPrice   -  The price at which the position will be closed for profit.
//|      CurrentOrderType  -  Is the impending order type (OP_BUY, OP_SELLLIMIT, etc).
//|      symbol            -  Symbol of the currency pair to use in the called routine. NULL means the current symbol.
//|                           By default, symbol is taken to be Symbol() unless specified otherwise as a passed parameter.
//|      verbose           -  Determines whether Print messages are committed to the experts log. By default, print messages are disabled.
//|
//|   Sample:
//|
//|      CurrentLotSize=0.1;              // setting the position size at a fixed 0.1 lots
//|      CurrentOpenPrice= Ask;           // setting the open price to current Ask price
//|      CurrentTakeProfitPrice= 92.361   // setting the stops at a fixed price of 92.361
//|      CurrentProfitPotential=ProfitPotential(CurrentLotSize,CurrentOpenPrice,CurrentTakeProfitPrice,OP_BUY,"USDJPY");
//|      Print("The calculated potential profit for the trade is ",CurrentProfitPotential);
//|
//+-----------------------+

double ProfitPotential(double LotSize,double OpenPrice,double TakeProfitPrice,int CurrentOrderType,string symbol="NULL",bool verbose=false)
   {  // ProfitPotential body start
   string   CurrentSymbol=symbol;
   if(symbol=="NULL") CurrentSymbol=Symbol();
   
   int      CurrentSymbolType=SymbolType(CurrentSymbol);  // The type of currency pair represented by CurrentSymbol
            if(CurrentSymbolType==6)
               {
               Print("Internal Error in determination of SymbolType for currency pair ",CurrentSymbol,", exiting script without computing profit potential");
               return(0);
               }
   string   CurrentCounterPairForCross=CounterPairForCross(CurrentSymbol);  // The name of the financial instrument which is the counter currency pair to CurrentSymbol (relevant to crosses)
   
   double   CalculatedProfitPotential=0.;
   
   switch(CurrentSymbolType) // Determine the equity at risk based on the SymbolType for the financial instrument
      {
      case 1   :  switch(CurrentOrderType)
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedProfitPotential=MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(TakeProfitPrice-OpenPrice)/TakeProfitPrice; break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedProfitPotential=MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(OpenPrice-TakeProfitPrice)/TakeProfitPrice; break;
                     default           :  Print("Error encountered in the OrderType() routine for calculating the ProfitPotential"); // The expression did not generate a case value
                     }
                  break;
      case 2   :  switch(CurrentOrderType)
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedProfitPotential=MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(TakeProfitPrice-OpenPrice); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedProfitPotential=MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(OpenPrice-TakeProfitPrice); break;
                     default           :  Print("Error encountered in the OrderType() routine for calculating the ProfitPotential"); // The expression did not generate a case value
                     }
                  break;
      case 3   :  // e.g. Symbol() = CHFJPY, the counter currency is JPY and the USD is the base to the JPY in the pair USDJPY
                  // falls thru and is treated the same as SymbolType()==4 for the purpose of these calculations
      case 4   :  switch(CurrentOrderType)  // e.g. Symbol() = AUDCAD, the counter currency is CAD and the USD is the base to the CAD in the pair USDCAD
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedProfitPotential=MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(TakeProfitPrice-OpenPrice)/MarketInfo(CurrentCounterPairForCross,MODE_BID); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedProfitPotential=MarketInfo(CurrentSymbol,MODE_LOTSIZE)*LotSize*(OpenPrice-TakeProfitPrice)/MarketInfo(CurrentCounterPairForCross,MODE_ASK); break;
                     default           :  Print("Error encountered in the OrderType() routine for calculating the ProfitPotential"); // The expression did not generate a case value
                     }
                  break;
      case 5   :  switch(CurrentOrderType)  // e.g. Symbol() = EURGBP, the counter currency is GBP and the USD is the counter to the GBP in the pair GBPUSD
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedProfitPotential=MarketInfo(CurrentSymbol,MODE_LOTSIZE)*MarketInfo(CurrentCounterPairForCross,MODE_BID)*LotSize*(TakeProfitPrice-OpenPrice); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedProfitPotential=MarketInfo(CurrentSymbol,MODE_LOTSIZE)*MarketInfo(CurrentCounterPairForCross,MODE_ASK)*LotSize*(OpenPrice-TakeProfitPrice); break;
                     default           :  Print("Error encountered in the OrderType() routine for calculating the ProfitPotential"); // The expression did not generate a case value
                     }
                  break;
      default  :  Print("Error encountered in the SWITCH routine for calculating the ProfitPotential"); // The expression did not generate a case value
      }
   
   if(verbose==true) Print("The equity at risk with this trade is ",DoubleToStr(CalculatedProfitPotential,2));
   
   return(CalculatedProfitPotential);
   
   }  // ProfitPotential body end

// Program End

//+------------------------+
//|   LotSize()            |
//+========================+
//|
//|   double LotSize(double EquityAtRisk, double OpenPrice, double StopLossPrice, int CurrentOrderType, string symbol="NULL", bool ReturnNormalizedLots=false, bool verbose=false)
//|
//|   Computes the lotsize that will result in placing the specificed amount of equity at risk of loss equity in the event that the specified stoploss price is reached.
//|   Returns a double value representing the lotsize if possible, otherwise, it returns a zero value.
//|
//|   Parameters:
//|      EquityAtRisk      -  Maximum allowed equity to be lost in the event the stoploss price is reached
//|      OpenPrice         -  The proposed opening price for either a market order or a pending order
//|      StopLossPrice     -  The price at which point the stops will be activated and the position will be closed for total loss of the equity at risk.
//|      CurrentOrderType  -  Is the impending order going to be an OP_BUY or OP_SELL.
//|      symbol            -  Symbol of the currency pair to use in the called routine. NULL means the current symbol.
//|                           By default, symbol is taken to be Symbol() unless specified otherwise as a passed parameter.
//|      ReturnNormalizedLots -  Computes the normalized lotsize for the broker dependent on MODE_LOTSTEP and MODE_MINLOT.
//|      verbose           -  Determines whether Print messages are committed to the experts log. By default, print messages are disabled.
//|
//|   Sample:
//|
//|      CurrentOpenPrice= Ask;         // setting the open price to current Ask price
//|      CurrentStopLossPrice= 92.361;  // setting the stops at a fixed price of 92.361
//|      CurrentEquityAtRisk=500;       // Risk budget allows a loss of up to $500 per trade
//|      CurrentLotSize=LotSize(CurrentEquityAtRisk,CurrentOpenPrice,CurrentStopLossPrice,OP_BUY,"USDJPY");
//|      Print("The calculated lot size is ",CurrentLotSize");
//|
//+-----------------------+

double LotSize(double EquityAtRisk,double OpenPrice,double StopLossPrice,int CurrentOrderType,string symbol="NULL",bool ReturnNormalizedLots=false,bool verbose=false)
   {  // LotSize body start
   string   CurrentSymbol=symbol;
   if(symbol=="NULL") CurrentSymbol=Symbol();
   
   int      CurrentSymbolType=SymbolType(CurrentSymbol);  //|      CurrentSymbolType -  The type of currency pair represented by CurrentSymbol.
            if(CurrentSymbolType==6)
               {
               Print("Internal Error in determination of SymbolType for currency pair ",CurrentSymbol,", exiting script without computing Lotsize");
               return(0);
               }
   string   CurrentCounterPairForCross=CounterPairForCross(CurrentSymbol);  //|      CurrentCounterPairForCross -  The name of the financial instrument which is the counter currency pair to CurrentSymbol (relevant to crosses)
   
   double   CalculatedLotSize=0.;
   
   // Constant     Value   Description 
   // OP_BUY         0     Buying position.
   // OP_SELL        1     Selling position.
   // OP_BUYLIMIT    2     Buy limit pending position.
   // OP_SELLLIMIT   3     Sell limit pending position.
   // OP_BUYSTOP     4     Buy stop pending position.
   // OP_SELLSTOP    5     Sell stop pending position.
   
   switch(CurrentSymbolType) // Determine the equity at risk based on the SymbolType for the financial instrument
      {
      case 1   :  switch(CurrentOrderType)   // Currency Pairs with USD as base - e.g. USDJPY
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedLotSize=(-EquityAtRisk*StopLossPrice)/(MarketInfo(CurrentSymbol,MODE_LOTSIZE)*(StopLossPrice-OpenPrice)); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedLotSize=(-EquityAtRisk*StopLossPrice)/(MarketInfo(CurrentSymbol,MODE_LOTSIZE)*(OpenPrice-StopLossPrice)); break;
                     default           :  Print("Error encountered in the OrderType switch for calculating the LotSize"); // The expression did not generate a case value
                     }
                  break;
      case 2   :  switch(CurrentOrderType)   // Currency Pairs with USD as counter - e.g. EURUSD
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedLotSize=-EquityAtRisk/(MarketInfo(CurrentSymbol,MODE_LOTSIZE)*(StopLossPrice-OpenPrice)); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedLotSize=-EquityAtRisk/(MarketInfo(CurrentSymbol,MODE_LOTSIZE)*(OpenPrice-StopLossPrice)); break;
                     default           :  Print("Error encountered in the OrderType switch for calculating the LotSize"); // The expression did not generate a case value
                     }
                  break;
      case 3   :  // e.g. Symbol() = CHFJPY, the counter currency is JPY and the USD is the base to the JPY in the pair USDJPY
                  // falls thru and is treated the same as SymbolType()==4 for the purpose of these calculations
      case 4   :  switch(CurrentOrderType)  // e.g. Symbol() = AUDCAD, the counter currency is CAD and the USD is the base to the CAD in the pair USDCAD
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedLotSize=(-EquityAtRisk*MarketInfo(CurrentCounterPairForCross,MODE_BID))/(MarketInfo(CurrentSymbol,MODE_LOTSIZE)*(StopLossPrice-OpenPrice)); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedLotSize=(-EquityAtRisk*MarketInfo(CurrentCounterPairForCross,MODE_ASK))/(MarketInfo(CurrentSymbol,MODE_LOTSIZE)*(OpenPrice-StopLossPrice)); break;
                     default           :  Print("Error encountered in the OrderType switch for calculating the LotSize"); // The expression did not generate a case value
                     }
                  break;
      case 5   :  switch(CurrentOrderType)  // e.g. Symbol() = EURGBP, the counter currency is GBP and the USD is the counter to the GBP in the pair GBPUSD
                     {
                     case OP_BUY       :  // Long position
                     case OP_BUYLIMIT  :  // Long position
                     case OP_BUYSTOP   :  CalculatedLotSize=-EquityAtRisk/(MarketInfo(CurrentSymbol,MODE_LOTSIZE)*MarketInfo(CurrentCounterPairForCross,MODE_BID)*(StopLossPrice-OpenPrice)); break;
                     case OP_SELL      :  // Short position
                     case OP_SELLLIMIT :  // Short position
                     case OP_SELLSTOP  :  CalculatedLotSize=-EquityAtRisk/(MarketInfo(CurrentSymbol,MODE_LOTSIZE)*MarketInfo(CurrentCounterPairForCross,MODE_ASK)*(OpenPrice-StopLossPrice)); break;
                     default           :  Print("Error encountered in the OrderType switch for calculating the LotSize"); // The expression did not generate a case value
                     }
                  break;
      default  :  Print("Error encountered in the CurrentSymbolType switch for calculating the LotSize"); // The expression did not generate a case value
      }
   
   if(CalculatedLotSize<0) CalculatedLotSize=0;
   
   if(ReturnNormalizedLots==true) CalculatedLotSize=NormalizeLotSize(CalculatedLotSize);
   
   if(verbose==true) Print("The calculated lot size is ",CalculatedLotSize);
   
   return(CalculatedLotSize);
   
   }  // LotSize body end

// Program End

//+------------------------+
//|   NormalizeLotSize()   |
//+========================+
//|
//|   double NormalizeLotSize(double CurrentLotSize, string symbol="NULL", bool verbose=false)
//|
//|   Computes the normalized lotsize for the broker dependent on MODE_LOTSTEP and MODE_MINLOT for the specified currency pair.
//|   Returns a double value representing the largest normalized lotsize that is less than or equal to CurrentLotSize if possible, otherwise, it returns a zero value.
//|
//|   Parameters:
//|      CurrentLotSize -  Position size that is proposed for usage in an impending trade.
//|      symbol         -  Symbol of the currency pair to use in the called routine. NULL means the current symbol.
//|                        By default, symbol is taken to be Symbol() unless specified otherwise as a passed parameter.
//|      verbose        -  Determines whether Print messages are committed to the experts log. By default, print messages are disabled.
//|
//|   Sample:
//|
//|      CurrentLotSize=0.12345678                                      // previously calculated lotsize based on max allowed equity at risk
//|      NormalizedLotSize=NormalizeLotSize(CurrentLotSize,"USDJPY");   // determine the properly normalized (broker specific) lotsize
//|      Print("The normalized lot size is ",NormalizedLotSize");       // The normalized lot size is 0.12, for example
//|
//+-----------------------+

double NormalizeLotSize(double CurrentLotSize, string symbol="NULL", bool verbose=false)
   {  // NormalizeLotSize body start
   double   CalculatedNormalizeLotSize=0.;
   int      LotSizeDigits=0;

   string   CurrentSymbol=symbol;
   if(symbol=="NULL") CurrentSymbol=Symbol();
      
   LotSizeDigits=-MathRound(MathLog(MarketInfo(CurrentSymbol,MODE_LOTSTEP))/MathLog(10.)); // Number of digits after decimal point for the Lot for the current broker, like Digits for symbol prices
   
   CalculatedNormalizeLotSize=NormalizeDouble(MathFloor((CurrentLotSize-MarketInfo(CurrentSymbol,MODE_MINLOT))/MarketInfo(CurrentSymbol,MODE_LOTSTEP))*MarketInfo(CurrentSymbol,MODE_LOTSTEP)+MarketInfo(CurrentSymbol,MODE_MINLOT),LotSizeDigits);
   
   if(verbose==true) Print("The broker-normalized lotsize is ",DoubleToStr(CalculatedNormalizeLotSize,LotSizeDigits));
   
   return(CalculatedNormalizeLotSize);
   
   }  // NormalizeLotSize body end

// Program End

/*
   +------------------------------------------------------------------+
   |                                                                  |
   |   Revision History                                               |
   |                                                                  |
   +------------------------------------------------------------------+

 Objective: This include file contains the routines necessary for computing the equity at risk for a
            given trade position size (lotsize).
            
 2010 Worklog:
   
   Oct 29   Updating the call routines to have a parameter for user-specified symbol instead of assuming the current symbol is to be used.
   
   Oct 25   Duplicated the EquityAtRisk call function and substituted stoplossprice for takeprofit and renamed as the ProfitPotential() call function for clarity of use.
            Internalized the symboltype determination so that it no longer needs to be passed as a paramter.
   
   Oct 09   Modifying the LotSize() call function such that it is passed the openprice parameter and no longer assumes it to be current Bid/Ask
            as needed for the proper risk management of pending orders
   
   Jun 07   Changed NormalizeLotSize() to incorporate LotSizeDigits determination internally, no longer a passed parameter
            
   May 20   Removing StopLossPrice() and placing it in a new include file that will house various stoploss calculation implementations.
   
   May 03   Creating call function LotSize() and NormalizeLotSize().
   
   Apr 29   Creating call functions StopLossPrice() and EquityAtRisk().
   
*/


